@@ -102,6 +102,7 @@ atk_role_get_type (void)
       { ATK_ROLE_APPLICATION, "ATK_ROLE_APPLICATION", "application" },
       { ATK_ROLE_AUTOCOMPLETE, "ATK_ROLE_AUTOCOMPLETE", "autocomplete" },
       { ATK_ROLE_EDITBAR, "ATK_ROLE_EDITBAR", "editbar" },
+      { ATK_ROLE_EMBEDDED, "ATK_ROLE_EMBEDDED", "embedded" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -201,6 +202,7 @@ atk_state_type_get_type (void)
       { ATK_STATE_MANAGES_DESCENDANTS, "ATK_STATE_MANAGES_DESCENDANTS", "manages-descendants" },
       { ATK_STATE_INDETERMINATE, "ATK_STATE_INDETERMINATE", "indeterminate" },
       { ATK_STATE_TRUNCATED, "ATK_STATE_TRUNCATED", "truncated" },
+      { ATK_STATE_REQUIRED, "ATK_STATE_REQUIRED", "required" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
